==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/SortedArraySet.h <==
// public final class soot.jimple.spark.sets.SortedArraySet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal
// @dep_class aab9caaf46188a06 soot_jimple_spark_sets_SortedArraySet

// header file dependencies
// @dep_header soot_jimple_spark_sets_PointsToSetInternal

#include "soot/jimple/spark/sets/PointsToSetInternal.h"

#ifndef _JC_soot_jimple_spark_sets_SortedArraySet_H_
#define _JC_soot_jimple_spark_sets_SortedArraySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_P2SetFactory$object;
struct _jc_soot_jimple_spark_sets_P2SetVisitor$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs	_jc_soot_jimple_spark_sets_SortedArraySet$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs	_jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$refs	_jc_soot_jimple_spark_sets_SortedArraySet$refs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$nonrefs	_jc_soot_jimple_spark_sets_SortedArraySet$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$object	_jc_soot_jimple_spark_sets_SortedArraySet$object;

typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vmethods	_jc_soot_jimple_spark_sets_SortedArraySet$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vtable	_jc_soot_jimple_spark_sets_SortedArraySet$vtable;
typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vtype	_jc_soot_jimple_spark_sets_SortedArraySet$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_SortedArraySet$method$_init$8f5e280981fa5b4c(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$add$d59a0ff50967f265(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$addAll$fd15a284ffdcd6c2(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *);
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$contains$02376d8da2ac3eb2(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$forall$5f1f852b8ec923c1(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *);
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$add$d59a0ff50967f265;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$addAll$fd15a284ffdcd6c2;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$contains$02376d8da2ac3eb2;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$forall$5f1f852b8ec923c1;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$isEmpty$551bea84f4e0f0cb;

// Static methods
extern struct _jc_soot_jimple_spark_sets_P2SetFactory$object *_jc_soot_jimple_spark_sets_SortedArraySet$method$getFactory$004f55462b2bd7e8(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_SortedArraySet$vmethods {
	jboolean	(*add$d59a0ff50967f265)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
	jboolean	(*addAll$fd15a284ffdcd6c2)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *);
	jboolean	(*contains$02376d8da2ac3eb2)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
	jboolean	(*forall$5f1f852b8ec923c1)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_SortedArraySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_PointsToSetInternal$vmethods	soot_jimple_spark_sets_PointsToSetInternal;
	_jc_soot_jimple_spark_sets_SortedArraySet$vmethods	soot_jimple_spark_sets_SortedArraySet;
};

// Vtype
struct _jc_soot_jimple_spark_sets_SortedArraySet$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_SortedArraySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs {
	_jc_object_array	*nodes;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_SortedArraySet$refs {
    _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs	soot_jimple_spark_sets_SortedArraySet;
    _jc_soot_jimple_spark_sets_PointsToSetInternal$sub_refs	soot_jimple_spark_sets_PointsToSetInternal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_SortedArraySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_PointsToSetInternal$sub_nonrefs	soot_jimple_spark_sets_PointsToSetInternal;
    _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs	soot_jimple_spark_sets_SortedArraySet;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_SortedArraySet$object {
	_jc_soot_jimple_spark_sets_SortedArraySet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_SortedArraySet$vtype	*vtype;
	_jc_soot_jimple_spark_sets_SortedArraySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_SortedArraySet$vtype _jc_soot_jimple_spark_sets_SortedArraySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_SortedArraySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_SortedArraySet$class_object;

#endif	/* _JC_soot_jimple_spark_sets_SortedArraySet_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/SortedArraySet.h <==
// public final class soot.jimple.spark.sets.SortedArraySet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal
// @dep_class aab9caaf46188a06 soot_jimple_spark_sets_SortedArraySet

// header file dependencies
// @dep_header soot_jimple_spark_sets_PointsToSetInternal

#include "soot/jimple/spark/sets/PointsToSetInternal.h"

#ifndef _JC_soot_jimple_spark_sets_SortedArraySet_H_
#define _JC_soot_jimple_spark_sets_SortedArraySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_P2SetFactory$object;
struct _jc_soot_jimple_spark_sets_P2SetVisitor$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs	_jc_soot_jimple_spark_sets_SortedArraySet$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs	_jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$refs	_jc_soot_jimple_spark_sets_SortedArraySet$refs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$nonrefs	_jc_soot_jimple_spark_sets_SortedArraySet$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_SortedArraySet$object	_jc_soot_jimple_spark_sets_SortedArraySet$object;

typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vmethods	_jc_soot_jimple_spark_sets_SortedArraySet$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vtable	_jc_soot_jimple_spark_sets_SortedArraySet$vtable;
typedef const struct _jc_soot_jimple_spark_sets_SortedArraySet$vtype	_jc_soot_jimple_spark_sets_SortedArraySet$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_SortedArraySet$method$_init$8f5e280981fa5b4c(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$add$d59a0ff50967f265(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$addAll$fd15a284ffdcd6c2(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$contains$02376d8da2ac3eb2(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$forall$5f1f852b8ec923c1(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_sets_SortedArraySet$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$add$d59a0ff50967f265;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$addAll$fd15a284ffdcd6c2;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$contains$02376d8da2ac3eb2;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$forall$5f1f852b8ec923c1;
extern _jc_method _jc_soot_jimple_spark_sets_SortedArraySet$method_info$isEmpty$551bea84f4e0f0cb;

// Static methods
extern struct _jc_soot_jimple_spark_sets_P2SetFactory$object *_jc_soot_jimple_spark_sets_SortedArraySet$method$getFactory$004f55462b2bd7e8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_SortedArraySet$vmethods {
	jboolean	(*add$d59a0ff50967f265)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
	jboolean	(*addAll$fd15a284ffdcd6c2)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *) _JC_JCNI_ATTR;
	jboolean	(*contains$02376d8da2ac3eb2)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
	jboolean	(*forall$5f1f852b8ec923c1)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_spark_sets_SortedArraySet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_SortedArraySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_PointsToSetInternal$vmethods	soot_jimple_spark_sets_PointsToSetInternal;
	_jc_soot_jimple_spark_sets_SortedArraySet$vmethods	soot_jimple_spark_sets_SortedArraySet;
};

// Vtype
struct _jc_soot_jimple_spark_sets_SortedArraySet$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_SortedArraySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs {
	_jc_object_array	*nodes;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_SortedArraySet$refs {
    _jc_soot_jimple_spark_sets_SortedArraySet$sub_refs	soot_jimple_spark_sets_SortedArraySet;
    _jc_soot_jimple_spark_sets_PointsToSetInternal$sub_refs	soot_jimple_spark_sets_PointsToSetInternal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_SortedArraySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_PointsToSetInternal$sub_nonrefs	soot_jimple_spark_sets_PointsToSetInternal;
    _jc_soot_jimple_spark_sets_SortedArraySet$sub_nonrefs	soot_jimple_spark_sets_SortedArraySet;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_SortedArraySet$object {
	_jc_soot_jimple_spark_sets_SortedArraySet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_SortedArraySet$vtype	*vtype;
	_jc_soot_jimple_spark_sets_SortedArraySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_SortedArraySet$vtype _jc_soot_jimple_spark_sets_SortedArraySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_SortedArraySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_SortedArraySet$class_object;

#endif	/* _JC_soot_jimple_spark_sets_SortedArraySet_H_ */
